==> CRM64Pro-0.14.0-docs.zip: CRM64Pro-0.14.0-docs/html/group___sprite_m.js <==
var group___sprite_m =
[
    [ "CRM64Pro::Sprite", "class_c_r_m64_pro_1_1_sprite.html", [
      [ "info", "group___sprite_m.html#gaf5c07af9afeb8e28b82c03939d053404", null ],
      [ "getName", "group___sprite_m.html#ga4eec2f82caae3c2b7b266ed89fca28a2", null ],
      [ "getID", "group___sprite_m.html#gad710daae25edc27674152346376a7f5e", null ],
      [ "assignImage", "group___sprite_m.html#ga247b2d73abd065d7903c5ad9147b7fce", null ],
      [ "getImage", "group___sprite_m.html#ga27a046a6cc0de23864d9a266d11f2c69", null ],
      [ "setOffset", "group___sprite_m.html#gab40350b96ad6ee08180f012cbb69d82e", null ],
      [ "getOffset", "group___sprite_m.html#ga5e9341913ecb5dc6580e027a2e344455", null ],
      [ "pause", "group___sprite_m.html#ga7dc0619ed2bcc1900195a689034f59f3", null ],
      [ "resume", "group___sprite_m.html#gaa1a650a1b4a9a49db07c112b440a6675", null ],
      [ "status", "group___sprite_m.html#gad469ef6b779116a5c2d01a74729a9904", null ],
      [ "setSpeed", "group___sprite_m.html#gab78eb249d072dbd0d0698fa0c3c33bba", null ],
      [ "getAnimCount", "group___sprite_m.html#ga23a6940901f1a674bb2922f315b80b87", null ],
      [ "getAnimCurrent", "group___sprite_m.html#gab294fcdaed407df4bf519925cb381702", null ],
      [ "selectAnim", "group___sprite_m.html#gadeb21a860629d957d0a140bd2cb92974", null ],
      [ "setAnimType", "group___sprite_m.html#ga4a682ca3c52ab2acb26b64fe76d543f7", null ],
      [ "getAnimType", "group___sprite_m.html#ga58d144c1de029fea630200e2277fc1c2", null ],
      [ "setAnimState", "group___sprite_m.html#ga22322643298c84f75e1da1ad1e3c8bd1", null ],
      [ "getAnimState", "group___sprite_m.html#gab43f37e69f7c40b521fac78a1af6470b", null ],
      [ "orderAnimState", "group___sprite_m.html#gaf5ce984da6ead3f47606f601f8d9f771", null ],
      [ "setAnimHotSpot", "group___sprite_m.html#ga45fc4154983c5b1b78131bc5b38bd324", null ],
      [ "getAnimHotSpot", "group___sprite_m.html#ga0f1f2c6968c08f9a19fd1dc4de2b9080", null ],
      [ "setAnimRange", "group___sprite_m.html#ga8fc7648a0c9a2e9c30da8c862dd5a046", null ],
      [ "getAnimRange", "group___sprite_m.html#gaf5168adbf387ab3642ef879937ed8453", null ],
      [ "getFrameCount", "group___sprite_m.html#ga05871ba32e81149bc48a80859009aa1c", null ],
      [ "getFrameCurrent", "group___sprite_m.html#gaefc223a5686bcf02cf3e1daf81cd0474", null ],
      [ "selectFrame", "group___sprite_m.html#gab592c007ecd3ff8126916754f294c2e9", null ],
      [ "setFrameTime", "group___sprite_m.html#gadddfe644f2a76030e271cbb63f7ce91f", null ],
      [ "getFrameTime", "group___sprite_m.html#ga9335c76f86651985f31db7865e077cc5", null ],
      [ "setPosition", "group___sprite_m.html#gae002daede49e6c471abcc581fdc7b6f5", null ],
      [ "getX", "group___sprite_m.html#gaae1b5ee5ed4f3599eba24282d449c5b2", null ],
      [ "getY", "group___sprite_m.html#ga85f6f6374d3463ce4140a575535863c0", null ],
      [ "render", "group___sprite_m.html#ga443d58cf91ea5fb09019326cbd87541a", null ],
      [ "renderEx", "group___sprite_m.html#ga8ce46c0de33b9db05a98b329b63e9fe1", null ],
      [ "save", "group___sprite_m.html#ga746bd94acabd71d2fc7092ac0ea73eeb", null ],
      [ "save", "group___sprite_m.html#gabdc08548947831472c13cbf48f6f7d2e", null ]
    ] ],
    [ "CRM64Pro::SpriteMgr", "class_c_r_m64_pro_1_1_sprite_mgr.html", [
      [ "info", "group___sprite_m.html#gadd1e0b3b7c72eb9fdc1f57188420278f", null ],
      [ "create", "group___sprite_m.html#gab1a0866d60b442aa28813e58efa279ab", null ],
      [ "close", "group___sprite_m.html#gaa74d5c66f254ddcd0132d3590fe04e02", null ],
      [ "getCount", "group___sprite_m.html#ga495365b1ea8da520c6469babd887964a", null ],
      [ "setName", "group___sprite_m.html#ga81bb120784b73c8b1772275d20ddd42c", null ],
      [ "get", "group___sprite_m.html#gac4b52e5f9a437374fd1a3f9fb71a3149", null ],
      [ "child", "group___sprite_m.html#ga4c11ce46026798000a15dbd1df04b935", null ],
      [ "load", "group___sprite_m.html#ga4cf6e8c047d48aaabb7b23a7921274ea", null ],
      [ "load", "group___sprite_m.html#ga06dafc6658785ffdd5beb8d396b61621", null ],
      [ "remove", "group___sprite_m.html#gaef9d7d2baf28e40fccad402b64d25de3", null ],
      [ "exist", "group___sprite_m.html#ga45d361c6ba0626b9b1fff69e83ed0cfa", null ],
      [ "exist", "group___sprite_m.html#ga40818973099e11510eeb070bf1cfec06", null ]
    ] ],
    [ "SPR_TYPE_LOOP", "group___sprite_m.html#ga079fc993c297c84c8f5c0dcd80b5ae97", null ],
    [ "SPR_TYPE_PINGPONG", "group___sprite_m.html#gab56aa0a421c7f67f3e22c0c14de46db2", null ],
    [ "SPR_TYPE_ONESHOT", "group___sprite_m.html#ga18c2827b6a60edf8f389a970762d822e", null ],
    [ "SPR_STATE_NORMAL", "group___sprite_m.html#ga77948d1de35a5551121b05a8c40587c0", null ],
    [ "SPR_STATE_UP", "group___sprite_m.html#gab8cf43aee9233119893e7552a313b184", null ],
    [ "SPR_STATE_DOWN", "group___sprite_m.html#ga838b6a27dc18ce0f924098ff15229253", null ],
    [ "SPR_STATE_LEFT", "group___sprite_m.html#gaca2d237d023dcc0863df02ac8a566156", null ],
    [ "SPR_STATE_RIGHT", "group___sprite_m.html#ga4870a0213fa4e5a3002770b74c7e0da0", null ],
    [ "SPR_STATE_UPLEFT", "group___sprite_m.html#ga596082f45d475675b2239809ea44876e", null ],
    [ "SPR_STATE_UPRIGHT", "group___sprite_m.html#ga4331bc16c76fe4d270b0a647e833cbfc", null ],
    [ "SPR_STATE_DOWNLEFT", "group___sprite_m.html#ga9c5761b4ebdb535ad8fc2505e2b4c7f9", null ],
    [ "SPR_STATE_DOWNRIGHT", "group___sprite_m.html#ga1284072cc4bc8f08b2615e8a6ea8cfd8", null ],
    [ "SPR_GET_HIGHSTATE", "group___sprite_m.html#gaa5b235faec7b724d8c64097713fd7f5e", null ],
    [ "SPR_GET_LOWSTATE", "group___sprite_m.html#gad859dc84a72e5ab060dcfa6e47c7b79c", null ],
    [ "CRM64Pro::Sprite::info", "group___sprite_m.html#gaf5c07af9afeb8e28b82c03939d053404", null ],
    [ "CRM64Pro::Sprite::getName", "group___sprite_m.html#ga4eec2f82caae3c2b7b266ed89fca28a2", null ],
    [ "CRM64Pro::Sprite::getID", "group___sprite_m.html#gad710daae25edc27674152346376a7f5e", null ],
    [ "CRM64Pro::Sprite::assignImage", "group___sprite_m.html#ga247b2d73abd065d7903c5ad9147b7fce", null ],
    [ "CRM64Pro::Sprite::getImage", "group___sprite_m.html#ga27a046a6cc0de23864d9a266d11f2c69", null ],
    [ "CRM64Pro::Sprite::setOffset", "group___sprite_m.html#gab40350b96ad6ee08180f012cbb69d82e", null ],
    [ "CRM64Pro::Sprite::getOffset", "group___sprite_m.html#ga5e9341913ecb5dc6580e027a2e344455", null ],
    [ "CRM64Pro::Sprite::pause", "group___sprite_m.html#ga7dc0619ed2bcc1900195a689034f59f3", null ],
    [ "CRM64Pro::Sprite::resume", "group___sprite_m.html#gaa1a650a1b4a9a49db07c112b440a6675", null ],
    [ "CRM64Pro::Sprite::status", "group___sprite_m.html#gad469ef6b779116a5c2d01a74729a9904", null ],
    [ "CRM64Pro::Sprite::setSpeed", "group___sprite_m.html#gab78eb249d072dbd0d0698fa0c3c33bba", null ],
    [ "CRM64Pro::Sprite::getAnimCount", "group___sprite_m.html#ga23a6940901f1a674bb2922f315b80b87", null ],
    [ "CRM64Pro::Sprite::getAnimCurrent", "group___sprite_m.html#gab294fcdaed407df4bf519925cb381702", null ],
    [ "CRM64Pro::Sprite::selectAnim", "group___sprite_m.html#gadeb21a860629d957d0a140bd2cb92974", null ],
    [ "CRM64Pro::Sprite::setAnimType", "group___sprite_m.html#ga4a682ca3c52ab2acb26b64fe76d543f7", null ],
    [ "CRM64Pro::Sprite::getAnimType", "group___sprite_m.html#ga58d144c1de029fea630200e2277fc1c2", null ],
    [ "CRM64Pro::Sprite::setAnimState", "group___sprite_m.html#ga22322643298c84f75e1da1ad1e3c8bd1", null ],
    [ "CRM64Pro::Sprite::getAnimState", "group___sprite_m.html#gab43f37e69f7c40b521fac78a1af6470b", null ],
    [ "CRM64Pro::Sprite::orderAnimState", "group___sprite_m.html#gaf5ce984da6ead3f47606f601f8d9f771", null ],
    [ "CRM64Pro::Sprite::setAnimHotSpot", "group___sprite_m.html#ga45fc4154983c5b1b78131bc5b38bd324", null ],
    [ "CRM64Pro::Sprite::getAnimHotSpot", "group___sprite_m.html#ga0f1f2c6968c08f9a19fd1dc4de2b9080", null ],
    [ "CRM64Pro::Sprite::setAnimRange", "group___sprite_m.html#ga8fc7648a0c9a2e9c30da8c862dd5a046", null ],
    [ "CRM64Pro::Sprite::getAnimRange", "group___sprite_m.html#gaf5168adbf387ab3642ef879937ed8453", null ],
    [ "CRM64Pro::Sprite::getFrameCount", "group___sprite_m.html#ga05871ba32e81149bc48a80859009aa1c", null ],
    [ "CRM64Pro::Sprite::getFrameCurrent", "group___sprite_m.html#gaefc223a5686bcf02cf3e1daf81cd0474", null ],
    [ "CRM64Pro::Sprite::selectFrame", "group___sprite_m.html#gab592c007ecd3ff8126916754f294c2e9", null ],
    [ "CRM64Pro::Sprite::setFrameTime", "group___sprite_m.html#gadddfe644f2a76030e271cbb63f7ce91f", null ],
    [ "CRM64Pro::Sprite::getFrameTime", "group___sprite_m.html#ga9335c76f86651985f31db7865e077cc5", null ],
    [ "CRM64Pro::Sprite::setPosition", "group___sprite_m.html#gae002daede49e6c471abcc581fdc7b6f5", null ],
    [ "CRM64Pro::Sprite::getX", "group___sprite_m.html#gaae1b5ee5ed4f3599eba24282d449c5b2", null ],
    [ "CRM64Pro::Sprite::getY", "group___sprite_m.html#ga85f6f6374d3463ce4140a575535863c0", null ],
    [ "CRM64Pro::Sprite::render", "group___sprite_m.html#ga443d58cf91ea5fb09019326cbd87541a", null ],
    [ "CRM64Pro::Sprite::renderEx", "group___sprite_m.html#ga8ce46c0de33b9db05a98b329b63e9fe1", null ],
    [ "CRM64Pro::Sprite::save", "group___sprite_m.html#ga746bd94acabd71d2fc7092ac0ea73eeb", null ],
    [ "CRM64Pro::Sprite::save", "group___sprite_m.html#gabdc08548947831472c13cbf48f6f7d2e", null ],
    [ "CRM64Pro::SpriteMgr::info", "group___sprite_m.html#gadd1e0b3b7c72eb9fdc1f57188420278f", null ],
    [ "CRM64Pro::SpriteMgr::create", "group___sprite_m.html#gab1a0866d60b442aa28813e58efa279ab", null ],
    [ "CRM64Pro::SpriteMgr::close", "group___sprite_m.html#gaa74d5c66f254ddcd0132d3590fe04e02", null ],
    [ "CRM64Pro::SpriteMgr::getCount", "group___sprite_m.html#ga495365b1ea8da520c6469babd887964a", null ],
    [ "CRM64Pro::SpriteMgr::setName", "group___sprite_m.html#ga81bb120784b73c8b1772275d20ddd42c", null ],
    [ "CRM64Pro::SpriteMgr::get", "group___sprite_m.html#gac4b52e5f9a437374fd1a3f9fb71a3149", null ],
    [ "CRM64Pro::SpriteMgr::child", "group___sprite_m.html#ga4c11ce46026798000a15dbd1df04b935", null ],
    [ "CRM64Pro::SpriteMgr::load", "group___sprite_m.html#ga4cf6e8c047d48aaabb7b23a7921274ea", null ],
    [ "CRM64Pro::SpriteMgr::load", "group___sprite_m.html#ga06dafc6658785ffdd5beb8d396b61621", null ],
    [ "CRM64Pro::SpriteMgr::remove", "group___sprite_m.html#gaef9d7d2baf28e40fccad402b64d25de3", null ],
    [ "CRM64Pro::SpriteMgr::exist", "group___sprite_m.html#ga45d361c6ba0626b9b1fff69e83ed0cfa", null ],
    [ "CRM64Pro::SpriteMgr::exist", "group___sprite_m.html#ga40818973099e11510eeb070bf1cfec06", null ]
];

==> CRM64Pro-0.15.0-docs.zip: CRM64Pro-0.15.0-docs/html/group___sprite_m.js <==
var group___sprite_m =
[
    [ "CRM64Pro::Sprite", "class_c_r_m64_pro_1_1_sprite.html", [
      [ "info", "group___sprite_m.html#gaf5c07af9afeb8e28b82c03939d053404", null ],
      [ "getName", "group___sprite_m.html#ga4eec2f82caae3c2b7b266ed89fca28a2", null ],
      [ "getID", "group___sprite_m.html#gad710daae25edc27674152346376a7f5e", null ],
      [ "assignImage", "group___sprite_m.html#ga247b2d73abd065d7903c5ad9147b7fce", null ],
      [ "getImage", "group___sprite_m.html#ga27a046a6cc0de23864d9a266d11f2c69", null ],
      [ "setOffset", "group___sprite_m.html#gab40350b96ad6ee08180f012cbb69d82e", null ],
      [ "getOffset", "group___sprite_m.html#ga5e9341913ecb5dc6580e027a2e344455", null ],
      [ "pause", "group___sprite_m.html#ga7dc0619ed2bcc1900195a689034f59f3", null ],
      [ "resume", "group___sprite_m.html#gaa1a650a1b4a9a49db07c112b440a6675", null ],
      [ "status", "group___sprite_m.html#ga1aa545a6c4e4a3f643701d22f7059efa", null ],
      [ "setSpeed", "group___sprite_m.html#gab78eb249d072dbd0d0698fa0c3c33bba", null ],
      [ "getAnimCount", "group___sprite_m.html#ga23a6940901f1a674bb2922f315b80b87", null ],
      [ "getAnimCurrent", "group___sprite_m.html#gab294fcdaed407df4bf519925cb381702", null ],
      [ "selectAnim", "group___sprite_m.html#gadeb21a860629d957d0a140bd2cb92974", null ],
      [ "setAnimType", "group___sprite_m.html#gaa0f439d10b38be0abe756174e734c69b", null ],
      [ "getAnimType", "group___sprite_m.html#ga43028262f4d132ce82735dcae0c65ab8", null ],
      [ "setAnimState", "group___sprite_m.html#ga22322643298c84f75e1da1ad1e3c8bd1", null ],
      [ "getAnimState", "group___sprite_m.html#gab43f37e69f7c40b521fac78a1af6470b", null ],
      [ "orderAnimState", "group___sprite_m.html#gaf5ce984da6ead3f47606f601f8d9f771", null ],
      [ "setAnimHotSpot", "group___sprite_m.html#ga45fc4154983c5b1b78131bc5b38bd324", null ],
      [ "getAnimHotSpot", "group___sprite_m.html#ga0f1f2c6968c08f9a19fd1dc4de2b9080", null ],
      [ "setAnimRange", "group___sprite_m.html#ga8fc7648a0c9a2e9c30da8c862dd5a046", null ],
      [ "getAnimRange", "group___sprite_m.html#gaf5168adbf387ab3642ef879937ed8453", null ],
      [ "getFrameCount", "group___sprite_m.html#ga05871ba32e81149bc48a80859009aa1c", null ],
      [ "getFrameCurrent", "group___sprite_m.html#gaefc223a5686bcf02cf3e1daf81cd0474", null ],
      [ "selectFrame", "group___sprite_m.html#gab592c007ecd3ff8126916754f294c2e9", null ],
      [ "setFrameTime", "group___sprite_m.html#gadddfe644f2a76030e271cbb63f7ce91f", null ],
      [ "getFrameTime", "group___sprite_m.html#ga9335c76f86651985f31db7865e077cc5", null ],
      [ "setPosition", "group___sprite_m.html#gae002daede49e6c471abcc581fdc7b6f5", null ],
      [ "getX", "group___sprite_m.html#gaae1b5ee5ed4f3599eba24282d449c5b2", null ],
      [ "getY", "group___sprite_m.html#ga85f6f6374d3463ce4140a575535863c0", null ],
      [ "render", "group___sprite_m.html#ga443d58cf91ea5fb09019326cbd87541a", null ],
      [ "renderEx", "group___sprite_m.html#ga027041a9ee51fa1d19e41edb5e1b5c2d", null ],
      [ "save", "group___sprite_m.html#ga746bd94acabd71d2fc7092ac0ea73eeb", null ],
      [ "save", "group___sprite_m.html#gabdc08548947831472c13cbf48f6f7d2e", null ]
    ] ],
    [ "CRM64Pro::SpriteMgr", "class_c_r_m64_pro_1_1_sprite_mgr.html", [
      [ "info", "group___sprite_m.html#gadd1e0b3b7c72eb9fdc1f57188420278f", null ],
      [ "create", "group___sprite_m.html#gab1a0866d60b442aa28813e58efa279ab", null ],
      [ "close", "group___sprite_m.html#gaa74d5c66f254ddcd0132d3590fe04e02", null ],
      [ "getCount", "group___sprite_m.html#ga495365b1ea8da520c6469babd887964a", null ],
      [ "setName", "group___sprite_m.html#ga81bb120784b73c8b1772275d20ddd42c", null ],
      [ "get", "group___sprite_m.html#gac4b52e5f9a437374fd1a3f9fb71a3149", null ],
      [ "child", "group___sprite_m.html#ga4c11ce46026798000a15dbd1df04b935", null ],
      [ "load", "group___sprite_m.html#ga4cf6e8c047d48aaabb7b23a7921274ea", null ],
      [ "load", "group___sprite_m.html#ga06dafc6658785ffdd5beb8d396b61621", null ],
      [ "loadFromBuffer", "group___sprite_m.html#ga8e9494fc527454c312448a1f8bd8309f", null ],
      [ "remove", "group___sprite_m.html#gaef9d7d2baf28e40fccad402b64d25de3", null ],
      [ "exist", "group___sprite_m.html#ga45d361c6ba0626b9b1fff69e83ed0cfa", null ],
      [ "exist", "group___sprite_m.html#ga40818973099e11510eeb070bf1cfec06", null ]
    ] ],
    [ "SPR_STATE_NORMAL", "group___sprite_m.html#ga77948d1de35a5551121b05a8c40587c0", null ],
    [ "SPR_STATE_UP", "group___sprite_m.html#gab8cf43aee9233119893e7552a313b184", null ],
    [ "SPR_STATE_DOWN", "group___sprite_m.html#ga838b6a27dc18ce0f924098ff15229253", null ],
    [ "SPR_STATE_LEFT", "group___sprite_m.html#gaca2d237d023dcc0863df02ac8a566156", null ],
    [ "SPR_STATE_RIGHT", "group___sprite_m.html#ga4870a0213fa4e5a3002770b74c7e0da0", null ],
    [ "SPR_STATE_UPLEFT", "group___sprite_m.html#ga596082f45d475675b2239809ea44876e", null ],
    [ "SPR_STATE_UPRIGHT", "group___sprite_m.html#ga4331bc16c76fe4d270b0a647e833cbfc", null ],
    [ "SPR_STATE_DOWNLEFT", "group___sprite_m.html#ga9c5761b4ebdb535ad8fc2505e2b4c7f9", null ],
    [ "SPR_STATE_DOWNRIGHT", "group___sprite_m.html#ga1284072cc4bc8f08b2615e8a6ea8cfd8", null ],
    [ "SPR_GET_HIGHSTATE", "group___sprite_m.html#gaa5b235faec7b724d8c64097713fd7f5e", null ],
    [ "SPR_GET_LOWSTATE", "group___sprite_m.html#gad859dc84a72e5ab060dcfa6e47c7b79c", null ],
    [ "CRM64Pro::eSpriteType", "group___sprite_m.html#ga081625e57922f79dff4b596ea035d668", null ],
    [ "CRM64Pro::Sprite::info", "group___sprite_m.html#gaf5c07af9afeb8e28b82c03939d053404", null ],
    [ "CRM64Pro::Sprite::getName", "group___sprite_m.html#ga4eec2f82caae3c2b7b266ed89fca28a2", null ],
    [ "CRM64Pro::Sprite::getID", "group___sprite_m.html#gad710daae25edc27674152346376a7f5e", null ],
    [ "CRM64Pro::Sprite::assignImage", "group___sprite_m.html#ga247b2d73abd065d7903c5ad9147b7fce", null ],
    [ "CRM64Pro::Sprite::getImage", "group___sprite_m.html#ga27a046a6cc0de23864d9a266d11f2c69", null ],
    [ "CRM64Pro::Sprite::setOffset", "group___sprite_m.html#gab40350b96ad6ee08180f012cbb69d82e", null ],
    [ "CRM64Pro::Sprite::getOffset", "group___sprite_m.html#ga5e9341913ecb5dc6580e027a2e344455", null ],
    [ "CRM64Pro::Sprite::pause", "group___sprite_m.html#ga7dc0619ed2bcc1900195a689034f59f3", null ],
    [ "CRM64Pro::Sprite::resume", "group___sprite_m.html#gaa1a650a1b4a9a49db07c112b440a6675", null ],
    [ "CRM64Pro::Sprite::status", "group___sprite_m.html#ga1aa545a6c4e4a3f643701d22f7059efa", null ],
    [ "CRM64Pro::Sprite::setSpeed", "group___sprite_m.html#gab78eb249d072dbd0d0698fa0c3c33bba", null ],
    [ "CRM64Pro::Sprite::getAnimCount", "group___sprite_m.html#ga23a6940901f1a674bb2922f315b80b87", null ],
    [ "CRM64Pro::Sprite::getAnimCurrent", "group___sprite_m.html#gab294fcdaed407df4bf519925cb381702", null ],
    [ "CRM64Pro::Sprite::selectAnim", "group___sprite_m.html#gadeb21a860629d957d0a140bd2cb92974", null ],
    [ "CRM64Pro::Sprite::setAnimType", "group___sprite_m.html#gaa0f439d10b38be0abe756174e734c69b", null ],
    [ "CRM64Pro::Sprite::getAnimType", "group___sprite_m.html#ga43028262f4d132ce82735dcae0c65ab8", null ],
    [ "CRM64Pro::Sprite::setAnimState", "group___sprite_m.html#ga22322643298c84f75e1da1ad1e3c8bd1", null ],
    [ "CRM64Pro::Sprite::getAnimState", "group___sprite_m.html#gab43f37e69f7c40b521fac78a1af6470b", null ],
    [ "CRM64Pro::Sprite::orderAnimState", "group___sprite_m.html#gaf5ce984da6ead3f47606f601f8d9f771", null ],
    [ "CRM64Pro::Sprite::setAnimHotSpot", "group___sprite_m.html#ga45fc4154983c5b1b78131bc5b38bd324", null ],
    [ "CRM64Pro::Sprite::getAnimHotSpot", "group___sprite_m.html#ga0f1f2c6968c08f9a19fd1dc4de2b9080", null ],
    [ "CRM64Pro::Sprite::setAnimRange", "group___sprite_m.html#ga8fc7648a0c9a2e9c30da8c862dd5a046", null ],
    [ "CRM64Pro::Sprite::getAnimRange", "group___sprite_m.html#gaf5168adbf387ab3642ef879937ed8453", null ],
    [ "CRM64Pro::Sprite::getFrameCount", "group___sprite_m.html#ga05871ba32e81149bc48a80859009aa1c", null ],
    [ "CRM64Pro::Sprite::getFrameCurrent", "group___sprite_m.html#gaefc223a5686bcf02cf3e1daf81cd0474", null ],
    [ "CRM64Pro::Sprite::selectFrame", "group___sprite_m.html#gab592c007ecd3ff8126916754f294c2e9", null ],
    [ "CRM64Pro::Sprite::setFrameTime", "group___sprite_m.html#gadddfe644f2a76030e271cbb63f7ce91f", null ],
    [ "CRM64Pro::Sprite::getFrameTime", "group___sprite_m.html#ga9335c76f86651985f31db7865e077cc5", null ],
    [ "CRM64Pro::Sprite::setPosition", "group___sprite_m.html#gae002daede49e6c471abcc581fdc7b6f5", null ],
    [ "CRM64Pro::Sprite::getX", "group___sprite_m.html#gaae1b5ee5ed4f3599eba24282d449c5b2", null ],
    [ "CRM64Pro::Sprite::getY", "group___sprite_m.html#ga85f6f6374d3463ce4140a575535863c0", null ],
    [ "CRM64Pro::Sprite::render", "group___sprite_m.html#ga443d58cf91ea5fb09019326cbd87541a", null ],
    [ "CRM64Pro::Sprite::renderEx", "group___sprite_m.html#ga027041a9ee51fa1d19e41edb5e1b5c2d", null ],
    [ "CRM64Pro::Sprite::save", "group___sprite_m.html#ga746bd94acabd71d2fc7092ac0ea73eeb", null ],
    [ "CRM64Pro::Sprite::save", "group___sprite_m.html#gabdc08548947831472c13cbf48f6f7d2e", null ],
    [ "CRM64Pro::SpriteMgr::info", "group___sprite_m.html#gadd1e0b3b7c72eb9fdc1f57188420278f", null ],
    [ "CRM64Pro::SpriteMgr::create", "group___sprite_m.html#gab1a0866d60b442aa28813e58efa279ab", null ],
    [ "CRM64Pro::SpriteMgr::close", "group___sprite_m.html#gaa74d5c66f254ddcd0132d3590fe04e02", null ],
    [ "CRM64Pro::SpriteMgr::getCount", "group___sprite_m.html#ga495365b1ea8da520c6469babd887964a", null ],
    [ "CRM64Pro::SpriteMgr::setName", "group___sprite_m.html#ga81bb120784b73c8b1772275d20ddd42c", null ],
    [ "CRM64Pro::SpriteMgr::get", "group___sprite_m.html#gac4b52e5f9a437374fd1a3f9fb71a3149", null ],
    [ "CRM64Pro::SpriteMgr::child", "group___sprite_m.html#ga4c11ce46026798000a15dbd1df04b935", null ],
    [ "CRM64Pro::SpriteMgr::load", "group___sprite_m.html#ga4cf6e8c047d48aaabb7b23a7921274ea", null ],
    [ "CRM64Pro::SpriteMgr::load", "group___sprite_m.html#ga06dafc6658785ffdd5beb8d396b61621", null ],
    [ "CRM64Pro::SpriteMgr::loadFromBuffer", "group___sprite_m.html#ga8e9494fc527454c312448a1f8bd8309f", null ],
    [ "CRM64Pro::SpriteMgr::remove", "group___sprite_m.html#gaef9d7d2baf28e40fccad402b64d25de3", null ],
    [ "CRM64Pro::SpriteMgr::exist", "group___sprite_m.html#ga45d361c6ba0626b9b1fff69e83ed0cfa", null ],
    [ "CRM64Pro::SpriteMgr::exist", "group___sprite_m.html#ga40818973099e11510eeb070bf1cfec06", null ]
];
